package com.hw.ems.base.mapper;

import java.util.List;
import com.hw.ems.base.domain.BaseCollectCommunicate;

/**
 * 集中器通讯信息Mapper接口
 *
 * @author hw
 * @date 2023-04-20
 */
public interface BaseCollectCommunicateMapper
{
    /**
     * 查询集中器通讯信息
     *
     * @param objid 集中器通讯信息主键
     * @return 集中器通讯信息
     */
    public BaseCollectCommunicate selectBaseCollectCommunicateByObjid(Long objid);

    /**
     * 查询集中器通讯信息列表
     *
     * @param baseCollectCommunicate 集中器通讯信息
     * @return 集中器通讯信息集合
     */
    public List<BaseCollectCommunicate> selectBaseCollectCommunicateList(BaseCollectCommunicate baseCollectCommunicate);

    /**
     * 新增集中器通讯信息
     *
     * @param baseCollectCommunicate 集中器通讯信息
     * @return 结果
     */
    public int insertBaseCollectCommunicate(BaseCollectCommunicate baseCollectCommunicate);

    /**
     * 修改集中器通讯信息
     *
     * @param baseCollectCommunicate 集中器通讯信息
     * @return 结果
     */
    public int updateBaseCollectCommunicate(BaseCollectCommunicate baseCollectCommunicate);

    /**
     * 删除集中器通讯信息
     *
     * @param objid 集中器通讯信息主键
     * @return 结果
     */
    public int deleteBaseCollectCommunicateByObjid(Long objid);

    /**
     * 批量删除集中器通讯信息
     *
     * @param objids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBaseCollectCommunicateByObjids(Long[] objids);
}
